pub enum Feature {
Core(ApiVersion),
Extension(Extension),
}Available on crate feature
unstable only.Expand description
A union type of extensions and core API version.
In vk.xml, Vulkan commands and types are grouped under different API version and extensions.
The tag of those group XML elements is feature or extension. One command will have only one
single correspondent feature. This type is mostly used to tell if a command should be returned
by vkGet*ProcAddr given the supported/enabled Vulkan API version and extensions.
Variants